"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const node_fs_1 = require("node:fs");
const commander_1 = require("commander");
const logger_js_1 = __importDefault(require("../../logger.js"));
const style_dictionary_generator_js_1 = __importDefault(require("../../style-dictionary/style-dictionary-generator.js"));
const parser_js_1 = __importDefault(require("../../tokens-metadata/parser.js"));
const utils_js_1 = require("../../utils.js");
const options_js_1 = require("../options.js");
const packageJson = (0, utils_js_1.getPackageJson)();
const cleanCommand = (0, commander_1.createCommand)('clean')
    .version(packageJson.version ?? 'unknown')
    .description('Remove the generated files')
    .action((options) => {
    try {
        const tokensMetadata = (0, parser_js_1.default)(options);
        logger_js_1.default.success('Tokens metadata parsed');
        logger_js_1.default.start('Clean generated files');
        logger_js_1.default.group();
        const styleDictionaryGenerator = new style_dictionary_generator_js_1.default(options, tokensMetadata);
        for (const file of styleDictionaryGenerator.listGeneratedFiles()) {
            logger_js_1.default.info('Delete file', file);
            (0, node_fs_1.rmSync)(file, { force: true });
        }
        logger_js_1.default.groupEnd();
        logger_js_1.default.newLine();
        logger_js_1.default.completed('Clean completed');
    }
    catch (error) {
        logger_js_1.default.newLine();
        logger_js_1.default.error('Clean error', error);
        logger_js_1.default.newLine();
        process.exitCode = 1;
    }
});
(0, options_js_1.addInputOption)(cleanCommand);
(0, options_js_1.addCssOutputOption)(cleanCommand);
(0, options_js_1.addIosOutputOption)(cleanCommand);
(0, options_js_1.addAndroidOutputOption)(cleanCommand);
(0, options_js_1.addTargetPlatformOption)(cleanCommand);
exports.default = cleanCommand;
