"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const commander_1 = require("commander");
const logger_js_1 = __importDefault(require("../../logger.js"));
const style_dictionary_generator_js_1 = __importDefault(require("../../style-dictionary/style-dictionary-generator.js"));
const parser_js_1 = __importDefault(require("../../tokens-metadata/parser.js"));
const tokens_studio_transformer_js_1 = require("../../tokens-studio/tokens-studio-transformer.js");
const utils_js_1 = require("../../utils.js");
const options_js_1 = require("../options.js");
const packageJson = (0, utils_js_1.getPackageJson)();
const generateCommand = (0, commander_1.createCommand)('generate')
    .description('Generate platform files from a Quartz design tokens JSON file.')
    .version(packageJson.version ?? 'unknown')
    .description('Builds the Quartz dictionary artifacts.')
    .action(async (options) => {
    try {
        const tokensMetadata = (0, parser_js_1.default)(options);
        logger_js_1.default.success('Tokens metadata parsed');
        const tokensStudioTransformer = new tokens_studio_transformer_js_1.TokensStudioTransformer(tokensMetadata);
        tokensStudioTransformer.generateStyleDictionaryTokens();
        logger_js_1.default.success('Style Dictionary input tokens generated');
        const styleDictionaryGenerator = new style_dictionary_generator_js_1.default(options, tokensMetadata);
        styleDictionaryGenerator.generateTargetPlatforms();
        logger_js_1.default.newLine();
        logger_js_1.default.completed('Build successful 🎉');
    }
    catch (error) {
        logger_js_1.default.newLine();
        logger_js_1.default.error('Generation error', error);
        logger_js_1.default.newLine();
        process.exitCode = 1;
    }
});
(0, options_js_1.addInputOption)(generateCommand);
(0, options_js_1.addCssOutputOption)(generateCommand);
(0, options_js_1.addIosOutputOption)(generateCommand);
(0, options_js_1.addAndroidOutputOption)(generateCommand);
(0, options_js_1.addTargetPlatformOption)(generateCommand);
(0, options_js_1.addCopyrightOption)(generateCommand);
(0, options_js_1.addCopyrightYearOption)(generateCommand);
exports.default = generateCommand;
