"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("../all/filter");
const transform_1 = require("../all/transform");
const transform_2 = require("./transform");
function getFile(destination) {
    return {
        destination: `${destination}.xml`,
        format: 'android/resources',
        filter: filter_1.excludeUndefined.name,
        options: {
            fileHeader: 'copyrightHeader',
        },
    };
}
class AndroidPlatformConfigurator {
    cliOptions;
    constructor(options) {
        this.cliOptions = options;
    }
    // eslint-disable-next-line class-methods-use-this
    getCustomTransforms() {
        return [transform_2.platformNameTransform, transform_2.themeNameTransform];
    }
    // eslint-disable-next-line class-methods-use-this
    getCustomTransformGroups() {
        const sharedTransforms = [
            transform_1.flagUndefinedValue.name,
            'color/hex8android',
            'size/remToSp',
            'size/remToDp',
        ];
        return [
            {
                name: 'qds-platform-android',
                transforms: [transform_2.platformNameTransform.name, ...sharedTransforms],
            },
            {
                name: 'qds-theme-android',
                transforms: [transform_2.themeNameTransform.name, ...sharedTransforms],
            },
        ];
    }
    getConfigForQuartzPlatform(platform) {
        return {
            buildPath: `${this.cliOptions.androidOutput}/`,
            transformGroup: 'qds-platform-android',
            files: [getFile(platform.nameWithPrefix)],
        };
    }
    getConfigForQuartzTheme(theme) {
        return {
            buildPath: `${this.cliOptions.androidOutput}/`,
            transformGroup: 'qds-theme-android',
            files: [getFile(theme.nameWithPrefix)],
        };
    }
}
exports.default = AndroidPlatformConfigurator;
