"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("../all/filter");
const transform_1 = require("../all/transform");
const transform_2 = require("./transform");
function getFile(destination, selector) {
    return {
        destination: `${destination}.css`,
        format: 'css/variables',
        filter: filter_1.excludeUndefined.name,
        options: {
            fileHeader: 'copyrightHeader',
            selector,
        },
    };
}
class CSSPlatformConfigurator {
    cliOptions;
    typographyTransform;
    constructor(options, tokensMetadata) {
        this.cliOptions = options;
        this.typographyTransform = (0, transform_2.getTypographyTransform)(tokensMetadata);
    }
    getCustomTransforms() {
        return [
            transform_2.platformNameTransform,
            transform_2.themeNameTransform,
            transform_2.blurTransform,
            transform_2.borderRadiusTransform,
            transform_2.borderWidthTransform,
            transform_2.breakpointTransform,
            transform_2.dropShadowTransform,
            transform_2.durationTransform,
            transform_2.spacingTransform,
            transform_2.sizingTransform,
            this.typographyTransform,
        ];
    }
    getCustomTransformGroups() {
        const sharedTransforms = [
            transform_1.flagUndefinedValue.name,
            transform_2.blurTransform.name,
            transform_2.borderRadiusTransform.name,
            transform_2.borderWidthTransform.name,
            transform_2.breakpointTransform.name,
            'color/css',
            transform_2.dropShadowTransform.name,
            transform_2.durationTransform.name,
            transform_2.spacingTransform.name,
            transform_2.sizingTransform.name,
            this.typographyTransform.name,
        ];
        return [
            {
                name: 'qds-platform-css',
                transforms: [transform_2.platformNameTransform.name, ...sharedTransforms],
            },
            {
                name: 'qds-theme-css',
                transforms: [transform_2.themeNameTransform.name, ...sharedTransforms],
            },
        ];
    }
    getConfigForQuartzPlatform(platform) {
        return {
            buildPath: `${this.cliOptions.cssOutput}/`,
            transformGroup: 'qds-platform-css',
            files: [
                getFile(platform.nameWithPrefix, `.qds-platform-${platform.name}`),
            ],
        };
    }
    getConfigForQuartzTheme(theme) {
        return {
            buildPath: `${this.cliOptions.cssOutput}/`,
            transformGroup: 'qds-theme-css',
            files: [getFile(theme.nameWithPrefix, `.qds-theme-${theme.name}`)],
        };
    }
}
exports.default = CSSPlatformConfigurator;
