"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
const utils_js_1 = require("../utils.js");
/**
 * Transform typography token into font shorthand syntax
 * https://developer.mozilla.org/en-US/docs/Web/CSS/font
 */
const FONT_WEIGHT_MAP = {
    regular: 'normal',
    bold: 'bold',
};
function replaceFontWeightValue(value) {
    return FONT_WEIGHT_MAP[value.toLowerCase()] ?? value;
}
function getTypographyTransform(tokensMetadata) {
    return {
        type: 'value',
        name: 'qds/typography/css',
        matcher: (token) => token.type === 'typography',
        transformer: (token) => {
            const typography = token.value;
            const fontFamily = tokensMetadata.cssFontFamilyReverseMap.get(typography.fontFamily) ??
                typography.fontFamily;
            return `${replaceFontWeightValue(typography.fontWeight)} ${(0, utils_js_1.toRem)(typography.fontSize)}/${(0, utils_js_1.toRem)(typography.lineHeight)} ${fontFamily}`;
        },
    };
}
exports.default = getTypographyTransform;
