"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
const filter_1 = require("../all/filter");
const transform_1 = require("../all/transform");
const transform_2 = require("./transform");
function getFile(destination) {
    return {
        destination: `${destination}.swift`,
        format: 'ios-swift/class.swift',
        filter: filter_1.excludeUndefined.name,
        options: {
            fileHeader: 'copyrightHeader',
        },
    };
}
class IOSPlatformConfigurator {
    cliOptions;
    constructor(options) {
        this.cliOptions = options;
    }
    // eslint-disable-next-line class-methods-use-this
    getCustomTransforms() {
        return [transform_2.platformNameTransform, transform_2.themeNameTransform, transform_2.colorTransform];
    }
    // eslint-disable-next-line class-methods-use-this
    getCustomTransformGroups() {
        const sharedTransforms = [
            transform_1.flagUndefinedValue.name,
            transform_2.colorTransform.name,
            'content/swift/literal',
            'asset/swift/literal',
            'size/swift/remToCGFloat',
            'font/swift/literal',
        ];
        return [
            {
                name: 'qds-platform-ios',
                transforms: [transform_2.platformNameTransform.name, ...sharedTransforms],
            },
            {
                name: 'qds-theme-ios',
                transforms: [transform_2.themeNameTransform.name, ...sharedTransforms],
            },
        ];
    }
    getConfigForQuartzPlatform(platform) {
        return {
            buildPath: `${this.cliOptions.iosOutput}/`,
            transformGroup: 'qds-platform-ios',
            files: [getFile(platform.nameWithPrefix)],
        };
    }
    getConfigForQuartzTheme(theme) {
        return {
            buildPath: `${this.cliOptions.iosOutput}/`,
            transformGroup: 'qds-theme-ios',
            files: [getFile(theme.nameWithPrefix)],
        };
    }
}
exports.default = IOSPlatformConfigurator;
