"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
const utils_js_1 = require("../utils.js");
const quartz_platform_js_1 = require("./quartz-platform.js");
const quartz_theme_js_1 = require("./quartz-theme.js");
// REUSE-IgnoreStart
const DEFAULT_COPYRIGHT = 'SPDX-FileCopyrightText: © <year> Schneider Electric\n\nSPDX-License-Identifier: LGPL-2.1-only';
// REUSE-IgnoreEnd
function initCopyrightHeader(options) {
    let copyrightHeader = DEFAULT_COPYRIGHT;
    if (options.copyright)
        copyrightHeader = options.copyright;
    const year = options.copyrightYear || new Date().getFullYear();
    copyrightHeader = copyrightHeader.replace('<year>', year.toString());
    return copyrightHeader;
}
function parsePlatforms(rawInput) {
    const platforms = [];
    for (const key of Object.keys(rawInput)) {
        if ((0, quartz_platform_js_1.isQuartzPlatform)(key)) {
            platforms.push(new quartz_platform_js_1.QuartzPlatform(key));
        }
    }
    return platforms;
}
function parseThemes(rawInput) {
    const themes = [];
    for (const key of Object.keys(rawInput)) {
        if ((0, quartz_theme_js_1.isQuartzTheme)(key)) {
            themes.push(new quartz_theme_js_1.QuartzTheme(key));
        }
    }
    return themes;
}
function parseTokensMetadata(options) {
    const copyrightHeader = initCopyrightHeader(options);
    const rawSourceTokens = (0, utils_js_1.parseJsonFile)(options.input);
    const platforms = parsePlatforms(rawSourceTokens);
    const themes = parseThemes(rawSourceTokens);
    return {
        copyrightHeader,
        rawSourceTokens,
        platforms,
        themes,
        cssFontFamilyReverseMap: new Map(),
    };
}
exports.default = parseTokensMetadata;
