"use strict";
// SPDX-FileCopyrightText: © 2022 Schneider Electric
//
// SPDX-License-Identifier: LGPL-2.1-only
Object.defineProperty(exports, "__esModule", { value: true });
exports.TokensStudioTransformer = void 0;
// eslint-disable-next-line @typescript-eslint/no-unsafe-assignment, @typescript-eslint/no-require-imports, @typescript-eslint/no-var-requires, unicorn/prefer-module
const { transformTokens: tokensStudioTransform } = require('token-transformer');
class TokensStudioTransformer {
    tokensMetadata;
    rawFontFamilyTokens;
    constructor(tokensMetadata) {
        this.tokensMetadata = tokensMetadata;
        this.rawFontFamilyTokens = this.parsePrivateLayerFontFamilies();
        this.generateCSSFontFamilyReverseMap();
    }
    generateStyleDictionaryTokens() {
        for (const platform of this.tokensMetadata.platforms) {
            this.injectFontFamiliesInRawSourceTokens(platform);
            // eslint-disable-next-line @typescript-eslint/no-unsafe-call
            const styleDictionaryTokens = tokensStudioTransform(this.tokensMetadata.rawSourceTokens, ['private', platform.nameWithPrefix], ['private'], {});
            platform.styleDictionaryTokens = styleDictionaryTokens;
        }
        for (const theme of this.tokensMetadata.themes) {
            // eslint-disable-next-line @typescript-eslint/no-unsafe-call
            const styleDictionaryTokens = tokensStudioTransform(this.tokensMetadata.rawSourceTokens, ['private', theme.nameWithPrefix], ['private'], {});
            theme.styleDictionaryTokens = styleDictionaryTokens;
        }
    }
    parsePrivateLayerFontFamilies() {
        // eslint-disable-next-line @typescript-eslint/no-unsafe-call
        const privateLayerFontFamilyTokens = tokensStudioTransform(this.tokensMetadata.rawSourceTokens, ['private'], [], {});
        return privateLayerFontFamilyTokens.private.font.family;
    }
    generateCSSFontFamilyReverseMap() {
        for (const [name, family] of Object.entries(this.rawFontFamilyTokens)) {
            this.tokensMetadata.cssFontFamilyReverseMap.set(family.value, `var(--qds-font-family-${name})`);
        }
    }
    injectFontFamiliesInRawSourceTokens(platform) {
        const newFontToken = {
            font: {
                family: {},
            },
        };
        for (const [name, font] of Object.entries(this.rawFontFamilyTokens)) {
            newFontToken.font.family[name] = font;
        }
        Object.assign(this.tokensMetadata.rawSourceTokens[platform.nameWithPrefix], newFontToken);
    }
}
exports.TokensStudioTransformer = TokensStudioTransformer;
exports.default = TokensStudioTransformer;
